@@ -9,7 +9,8 @@ import re
 
 from typing import Optional
 
-from .tlds import tlds
+from refinery.lib.patterns.tlds import tlds
+from refinery.lib.tools import cached_property
 
 
 class pattern:
@@ -25,20 +26,25 @@ class pattern:
 
     def __init__(self, pattern: str):
         self.str_pattern = pattern
-        self.bin_pattern = None
-        self.bin_compiled = re.compile(B'(%s)' % self)
-        self.str_compiled = re.compile(self.str_pattern)
+        self.bin_pattern = pattern.encode('ascii')
 
     def __bytes__(self):
-        bin_pattern = self.bin_pattern
-        if bin_pattern is None:
-            self.bin_pattern = bin_pattern = self.str_pattern.encode('ascii')
-        return bin_pattern
+        return self.bin_pattern
+
+    @cached_property
+    def bin_compiled(self):
+        return re.compile(B'(%s)' % self.bin_pattern)
+
+    @cached_property
+    def str_compiled(self):
+        return re.compile(self.str_pattern)
 
     def __str__(self):
         return self.str_pattern
 
     def __getattr__(self, verb):
+        if not hasattr(re.Pattern, verb):
+            raise AttributeError(verb)
         bin_attr = getattr(self.bin_compiled, verb)
         if not callable(bin_attr):
             return bin_attr
@@ -212,7 +218,7 @@ _pattern_win_path_element = R'(?:{n} ){{0,4}}{n}'.format(n=_pattern_pathpart_nos
 _pattern_nix_path_element = R'(?:{n} ){{0,1}}{n}'.format(n=_pattern_pathpart_nospace)
 _pattern_win_env_variable = R'%[a-zA-Z][a-zA-Z0-9_\-\(\)]*%'
 
-_pattern_win_path = R'(?:{s})(?P<pathsep>[\\\/])(?:{p}(?P=pathsep))*{p}\b'.format(
+_pattern_win_path = R'(?:{s})(?P<pathsep>[\\\/])(?:{p}(?P=pathsep))*{p}(?:(?P=pathsep)|\b)'.format(
     s='|'.join([
         _pattern_win_env_variable,    # environment variable
         R'[A-Za-z]:',                 # drive letter with colon
