@@ -128,7 +128,7 @@ def documentation(unit):
     return docs.replace('`', '')
 
 
-def skipfirst(iterable):
+def skipfirst(iterable: Iterable[_T]) -> Generator[_T, None, None]:
     """
     Returns an interable where the first element of the input iterable was
     skipped.
@@ -272,8 +272,11 @@ def infinitize(it):
     return it
 
 
-def cached_property(p):
-    return property(functools.lru_cache(maxsize=1)(p))
+try:
+    cached_property = functools.cached_property
+except AttributeError:
+    def cached_property(p):
+        return property(functools.lru_cache(maxsize=1)(p))
 
 
 class NoLogging:
@@ -308,8 +311,10 @@ class NoLogging:
             warnings.resetwarnings()
             warnings.filters[:] = self._warning_filters
         if self.mode & NoLogging.Mode.STD_ERR:
+            sys.stderr.close()
             sys.stderr = self._stderr
         if self.mode & NoLogging.Mode.STD_OUT:
+            sys.stdout.close()
             sys.stdout = self._stdout
 
 
