@@ -2,14 +2,14 @@
 # -*- coding: utf-8 -*-
 import base64
 
-from refinery.units import arg, Unit
+from refinery.units import Arg, Unit
 
 
 class b64(Unit):
     """
     Base64 encoding and decoding.
     """
-    def __init__(self, urlsafe: arg.switch('-u', help='use URL-safe alphabet') = False):
+    def __init__(self, urlsafe: Arg.Switch('-u', help='use URL-safe alphabet') = False):
         super().__init__(urlsafe=urlsafe)
 
     @property
