@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from refinery.units import arg, Unit
+from refinery.units import Arg, Unit
 from refinery.lib.decorators import unicoded
 
 
@@ -8,7 +8,7 @@ class ppjscript(Unit):
     """
     Pretty-prints JavaScript without any reflection or evaluation.
     """
-    def __init__(self, indent: arg.number('-i', help=(
+    def __init__(self, indent: Arg.Number('-i', help=(
         'Controls the amount of space characters used for indentation in the output. Default is 4.')) = 4
     ):
         return super().__init__(indent=indent)
